# -*- coding: utf-8 -*-
from simple_manager.utils import git_clone
from shutil import copytree

import os


class Repository():

    def __init__(self, name, remote_url=None, description=None,
                 long_description=None, keywords=None,
                 author=None, email=None, version=None):
        self.name = name
        self.remote_url = remote_url
        self.description = description
        self.long_description = long_description
        self.keywords = keywords
        self.author = author
        self.email = email
        self.version = version

    def commit_changes(self):
        print("Commiting changes to {0}").format(self.remote_url)

    def extract_repo(self, frm, to):
        import git_repo_manager
        pkg_name = frm.split('/')[-1]
        path = os.path.join(to, self.name, pkg_name)

        git_clone(self.name, self.remote_url, to)

        print("Extracting code from {0} to {1}").format(frm, path)

        copytree(src=frm, dst=path)

        print("Generating necessary files do create a dist")
        print("  ... setup.py")

        with open(os.path.join(git_repo_manager.__path__[0],
                               "templates/README.md.conf"), 'r') as setup_tmpl:
            content = setup_tmpl.read()

        content = content.replace("$name", self.name)
        content = content.replace("$version", self.version)
        content = content.replace("$description", self.author)
        content = content.replace("$long_description", self.long_description)
        content = content.replace("$keywords", self.keywords)
        content = content.replace("$author", self.author)
        content = content.replace("$email", self.email)
        content = content.replace("$url", self.remote_url)
        content = content.replace("$pkg_dir", pkg_name)

        with open(os.path.join(git_repo_manager.__path__[0],
                   "templates/setup.py"), 'w') as setup_file:
            setup_file.write(content)

        print("  ... README.md")
        with open(os.path.join(git_repo_manager.__path__[0],
                               "templates/README.md.conf"), 'r') as rdm_tmpl:
            content = rdm_tmpl.read()

        content = content.replace("$name", self.name)
        content = content.replace("$description", self.author)

        with open(os.path.join(git_repo_manager.__path__[0],
                   "templates/README.md"), 'w') as rdm_file:
            rdm_file.write(content)

        self.commit_changes()


class GitoriousRepository(Repository):
    pass



# -*- coding: utf-8 -*-

from setuptools import setup, find_packages
from git_repo_manager import __version__ as Version

setup(
    name=u'git-repo-manager',
    version=Version,
    description=u"A simple script that helps you manage your git repos",
    long_description=u'''
    git_repo_manager allows users to create new git repositories based on a well defined template.

    Repositories can be managed directly via git-repo-manager.py script or by developer himself. In this last case, developer just have to import simple_manage as a python module.

    It also create a Jenkins Job for this new born repo.
    ''',
    keywords='git gitorius github manager repo repository repositories',
    author=u'Victor Pantoja',
    author_email='victor.pantoja@gmail.com',
    url='https://github.com/victorpantoja/git-repo-manager',
    license='MIT',
    classifiers=['Development Status :: 4 - Beta',
                 'Intended Audience :: Developers',
                 'Programming Language :: Python'],
    packages=find_packages(),
    package_dir={"git_repo_manager": "git_repo_manager"},
    include_package_data=True,
    scripts=['git_repo_manager/git-repo-manager.py'],

    install_requires=[
        "simple-dependencies-manager"
    ]
)



#!/usr/bin/python
# -*- coding: utf-8 -*-
from git_repo_manager import __version__ as Version
from git_repo_manager.classes import GitoriousRepository 
from optparse import OptionParser

import os
import sys

def validate(options):
    if not os.path.isdir(options.frm):
        print("{0} is not a dir.").format(options.frm)
        sys.exit(2)

    if not os.path.isdir(options.to):
        print("{0} is not a dir.").format(options.to)
        sys.exit(2)

    if not options.name:
        print("use -n to give your repo a name!")
        sys.exit(2)

    if not options.remote_url:
        print("use -u to provide remote url!")
        sys.exit(2)

    if options.extract_repo:
        if not options.frm or not options.to:
            print("usage: git-repo-manager.py -x -f /path/to/old/app -t /path/to/new/repo")
            sys.exit(2)

def main(argv):
    parser = OptionParser(version=Version)

    parser.add_option("-c", "--create-repo", dest="create_repo",
                      help="Task to create a new remote repo",
                      action="store_true")

    parser.add_option("-n", "--repo-name", dest="name",
                      help="Give your repo a name!",
                      metavar="NAME")

    parser.add_option("-f", "--from", dest="frm",
                      help="Path to migrate repo from",
                      metavar="FROM")

    parser.add_option("-t", "--to", dest="to",
                      help="Path do generate new repo",
                      metavar="TO")
    
    parser.add_option("-u", "--remote-url", dest="remote_url",
                      help="Remote URL",
                      metavar="URL")

    parser.add_option("-x", "--extract-repo", dest="extract_repo",
                      help="Task to extract a module and create a new repo",
                      action="store_true")
    
    (options, args) = parser.parse_args()
    
    validate(options)
    
    if options.extract_repo:
        #criar um factory para isso
        repo = GitoriousRepository(name=options.name)
        repo.remote_url = options.remote_url
        
        author = raw_input("Author: ")
        email = raw_input("Author email: ")
        version = raw_input("Version: ")
        description = raw_input("Short description: ")
        long_description = raw_input("Long description: ")
        keywords = raw_input("Keywords (comma separated): ")

        repo.description = description
        repo.long_description = long_description
        repo.keywords = keywords
        repo.author = author
        repo.email = email
        repo.version = version
        
        repo.extract_repo(frm=options.frm, to=options.to)

        ans = raw_input("Remove old files at {0}? [y] [n] ".format(options.frm))
        if ans == 'n' or ans == 'N':
            print("Old files not removed.")
            sys.exit(0)
        elif ans == 'y' or ans == 'Y':
            print("Removing files...'")

if __name__ == "__main__":
    main(sys.argv[1:])
